#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# @Author: José Sánchez-Gallego (gallegoj@uw.edu)
# @Date: 2018-11-02
# @Filename: catalogdb.py
# @License: BSD 3-clause (http://www.opensource.org/licenses/BSD-3-Clause)
#
# @Last modified by: José Sánchez-Gallego (gallegoj@uw.edu)
# @Last modified time: 2018-12-07 23:10:53


from peewee import (AutoField, BigAutoField, BigIntegerField, BooleanField, CharField,
                    DateField, DecimalField, DeferredThroughModel, FloatField,
                    ForeignKeyField, IntegerField, ManyToManyField, TextField)

from . import SDSS5dbModel, database  # noqa


class AllWise(SDSS5dbModel):
    designation = CharField(null=True)
    ra = DecimalField(index=True, null=True)
    dec = DecimalField(index=True, null=True)
    sigra = DecimalField(null=True)
    sigdec = DecimalField(null=True)
    sigradec = DecimalField(null=True)
    glon = DecimalField(index=True, null=True)
    glat = DecimalField(index=True, null=True)
    elon = DecimalField(null=True)
    elat = DecimalField(null=True)
    wx = DecimalField(null=True)
    wy = DecimalField(null=True)
    cntr = BigIntegerField(null=True)
    source_id = CharField(null=True)
    coadd_id = CharField(null=True)
    src = IntegerField(null=True)
    w1mpro = DecimalField(null=True)
    w1sigmpro = DecimalField(null=True)
    w1snr = DecimalField(null=True)
    w1rchi2 = FloatField(null=True)
    w2mpro = DecimalField(null=True)
    w2sigmpro = DecimalField(null=True)
    w2snr = DecimalField(null=True)
    w2rchi2 = FloatField(null=True)
    w3mpro = DecimalField(null=True)
    w3sigmpro = DecimalField(null=True)
    w3snr = DecimalField(null=True)
    w3rchi2 = FloatField(null=True)
    w4mpro = DecimalField(null=True)
    w4sigmpro = DecimalField(null=True)
    w4snr = DecimalField(null=True)
    w4rchi2 = FloatField(null=True)
    rchi2 = FloatField(null=True)
    nb = IntegerField(null=True)
    na = IntegerField(null=True)
    w1sat = DecimalField(null=True)
    w2sat = DecimalField(null=True)
    w3sat = DecimalField(null=True)
    w4sat = DecimalField(null=True)
    satnum = CharField(null=True)
    ra_pm = DecimalField(null=True)
    dec_pm = DecimalField(null=True)
    sigra_pm = DecimalField(null=True)
    sigdec_pm = DecimalField(null=True)
    sigradec_pm = DecimalField(null=True)
    pmra = IntegerField(null=True)
    sigpmra = IntegerField(null=True)
    pmdec = IntegerField(null=True)
    sigpmdec = IntegerField(null=True)
    w1rchi2_pm = FloatField(null=True)
    w2rchi2_pm = FloatField(null=True)
    w3rchi2_pm = FloatField(null=True)
    w4rchi2_pm = FloatField(null=True)
    rchi2_pm = FloatField(null=True)
    pmcode = CharField(null=True)
    cc_flags = CharField(null=True)
    rel = CharField(null=True)
    ext_flg = IntegerField(null=True)
    var_flg = CharField(null=True)
    ph_qual = CharField(null=True)
    det_bit = IntegerField(null=True)
    moon_lev = CharField(null=True)
    w1nm = IntegerField(null=True)
    w1m = IntegerField(null=True)
    w2nm = IntegerField(null=True)
    w2m = IntegerField(null=True)
    w3nm = IntegerField(null=True)
    w3m = IntegerField(null=True)
    w4nm = IntegerField(null=True)
    w4m = IntegerField(null=True)
    w1cov = DecimalField(null=True)
    w2cov = DecimalField(null=True)
    w3cov = DecimalField(null=True)
    w4cov = DecimalField(null=True)
    w1cc_map = IntegerField(null=True)
    w1cc_map_str = CharField(null=True)
    w2cc_map = IntegerField(null=True)
    w2cc_map_str = CharField(null=True)
    w3cc_map = IntegerField(null=True)
    w3cc_map_str = CharField(null=True)
    w4cc_map = IntegerField(null=True)
    w4cc_map_str = CharField(null=True)
    best_use_cntr = BigIntegerField(null=True)
    ngrp = IntegerField(null=True)
    w1flux = FloatField(null=True)
    w1sigflux = FloatField(null=True)
    w1sky = DecimalField(null=True)
    w1sigsk = DecimalField(null=True)
    w1conf = DecimalField(null=True)
    w2flux = FloatField(null=True)
    w2sigflux = FloatField(null=True)
    w2sky = DecimalField(null=True)
    w2sigsk = DecimalField(null=True)
    w2conf = DecimalField(null=True)
    w3flux = FloatField(null=True)
    w3sigflux = FloatField(null=True)
    w3sky = DecimalField(null=True)
    w3sigsk = DecimalField(null=True)
    w3conf = DecimalField(null=True)
    w4flux = FloatField(null=True)
    w4sigflux = FloatField(null=True)
    w4sky = DecimalField(null=True)
    w4sigsk = DecimalField(null=True)
    w4conf = DecimalField(null=True)
    w1mag = DecimalField(null=True)
    w1sigm = DecimalField(null=True)
    w1flg = IntegerField(null=True)
    w1mcor = DecimalField(null=True)
    w2mag = DecimalField(null=True)
    w2sigm = DecimalField(null=True)
    w2flg = IntegerField(null=True)
    w2mcor = DecimalField(null=True)
    w3mag = DecimalField(null=True)
    w3sigm = DecimalField(null=True)
    w3flg = IntegerField(null=True)
    w3mcor = DecimalField(null=True)
    w4mag = DecimalField(null=True)
    w4sigm = DecimalField(null=True)
    w4flg = IntegerField(null=True)
    w4mcor = DecimalField(null=True)
    w1mag_1 = DecimalField(null=True)
    w1sigm_1 = DecimalField(null=True)
    w1flg_1 = IntegerField(null=True)
    w2mag_1 = DecimalField(null=True)
    w2sigm_1 = DecimalField(null=True)
    w2flg_1 = IntegerField(null=True)
    w3mag_1 = DecimalField(null=True)
    w3sigm_1 = DecimalField(null=True)
    w3flg_1 = IntegerField(null=True)
    w4mag_1 = DecimalField(null=True)
    w4sigm_1 = DecimalField(null=True)
    w4flg_1 = IntegerField(null=True)
    w1mag_2 = DecimalField(null=True)
    w1sigm_2 = DecimalField(null=True)
    w1flg_2 = IntegerField(null=True)
    w2mag_2 = DecimalField(null=True)
    w2sigm_2 = DecimalField(null=True)
    w2flg_2 = IntegerField(null=True)
    w3mag_2 = DecimalField(null=True)
    w3sigm_2 = DecimalField(null=True)
    w3flg_2 = IntegerField(null=True)
    w4mag_2 = DecimalField(null=True)
    w4sigm_2 = DecimalField(null=True)
    w4flg_2 = IntegerField(null=True)
    w1mag_3 = DecimalField(null=True)
    w1sigm_3 = DecimalField(null=True)
    w1flg_3 = IntegerField(null=True)
    w2mag_3 = DecimalField(null=True)
    w2sigm_3 = DecimalField(null=True)
    w2flg_3 = IntegerField(null=True)
    w3mag_3 = DecimalField(null=True)
    w3sigm_3 = DecimalField(null=True)
    w3flg_3 = IntegerField(null=True)
    w4mag_3 = DecimalField(null=True)
    w4sigm_3 = DecimalField(null=True)
    w4flg_3 = IntegerField(null=True)
    w1mag_4 = DecimalField(null=True)
    w1sigm_4 = DecimalField(null=True)
    w1flg_4 = IntegerField(null=True)
    w2mag_4 = DecimalField(null=True)
    w2sigm_4 = DecimalField(null=True)
    w2flg_4 = IntegerField(null=True)
    w3mag_4 = DecimalField(null=True)
    w3sigm_4 = DecimalField(null=True)
    w3flg_4 = IntegerField(null=True)
    w4mag_4 = DecimalField(null=True)
    w4sigm_4 = DecimalField(null=True)
    w4flg_4 = IntegerField(null=True)
    w1mag_5 = DecimalField(null=True)
    w1sigm_5 = DecimalField(null=True)
    w1flg_5 = IntegerField(null=True)
    w2mag_5 = DecimalField(null=True)
    w2sigm_5 = DecimalField(null=True)
    w2flg_5 = IntegerField(null=True)
    w3mag_5 = DecimalField(null=True)
    w3sigm_5 = DecimalField(null=True)
    w3flg_5 = IntegerField(null=True)
    w4mag_5 = DecimalField(null=True)
    w4sigm_5 = DecimalField(null=True)
    w4flg_5 = IntegerField(null=True)
    w1mag_6 = DecimalField(null=True)
    w1sigm_6 = DecimalField(null=True)
    w1flg_6 = IntegerField(null=True)
    w2mag_6 = DecimalField(null=True)
    w2sigm_6 = DecimalField(null=True)
    w2flg_6 = IntegerField(null=True)
    w3mag_6 = DecimalField(null=True)
    w3sigm_6 = DecimalField(null=True)
    w3flg_6 = IntegerField(null=True)
    w4mag_6 = DecimalField(null=True)
    w4sigm_6 = DecimalField(null=True)
    w4flg_6 = IntegerField(null=True)
    w1mag_7 = DecimalField(null=True)
    w1sigm_7 = DecimalField(null=True)
    w1flg_7 = IntegerField(null=True)
    w2mag_7 = DecimalField(null=True)
    w2sigm_7 = DecimalField(null=True)
    w2flg_7 = IntegerField(null=True)
    w3mag_7 = DecimalField(null=True)
    w3sigm_7 = DecimalField(null=True)
    w3flg_7 = IntegerField(null=True)
    w4mag_7 = DecimalField(null=True)
    w4sigm_7 = DecimalField(null=True)
    w4flg_7 = IntegerField(null=True)
    w1mag_8 = DecimalField(null=True)
    w1sigm_8 = DecimalField(null=True)
    w1flg_8 = IntegerField(null=True)
    w2mag_8 = DecimalField(null=True)
    w2sigm_8 = DecimalField(null=True)
    w2flg_8 = IntegerField(null=True)
    w3mag_8 = DecimalField(null=True)
    w3sigm_8 = DecimalField(null=True)
    w3flg_8 = IntegerField(null=True)
    w4mag_8 = DecimalField(null=True)
    w4sigm_8 = DecimalField(null=True)
    w4flg_8 = IntegerField(null=True)
    w1magp = DecimalField(null=True)
    w1sigp1 = DecimalField(null=True)
    w1sigp2 = DecimalField(null=True)
    w1k = DecimalField(null=True)
    w1ndf = IntegerField(null=True)
    w1mlq = DecimalField(null=True)
    w1mjdmin = DecimalField(null=True)
    w1mjdmax = DecimalField(null=True)
    w1mjdmean = DecimalField(null=True)
    w2magp = DecimalField(null=True)
    w2sigp1 = DecimalField(null=True)
    w2sigp2 = DecimalField(null=True)
    w2k = DecimalField(null=True)
    w2ndf = IntegerField(null=True)
    w2mlq = DecimalField(null=True)
    w2mjdmin = DecimalField(null=True)
    w2mjdmax = DecimalField(null=True)
    w2mjdmean = DecimalField(null=True)
    w3magp = DecimalField(null=True)
    w3sigp1 = DecimalField(null=True)
    w3sigp2 = DecimalField(null=True)
    w3k = DecimalField(null=True)
    w3ndf = IntegerField(null=True)
    w3mlq = DecimalField(null=True)
    w3mjdmin = DecimalField(null=True)
    w3mjdmax = DecimalField(null=True)
    w3mjdmean = DecimalField(null=True)
    w4magp = DecimalField(null=True)
    w4sigp1 = DecimalField(null=True)
    w4sigp2 = DecimalField(null=True)
    w4k = DecimalField(null=True)
    w4ndf = IntegerField(null=True)
    w4mlq = DecimalField(null=True)
    w4mjdmin = DecimalField(null=True)
    w4mjdmax = DecimalField(null=True)
    w4mjdmean = DecimalField(null=True)
    rho12 = IntegerField(null=True)
    rho23 = IntegerField(null=True)
    rho34 = IntegerField(null=True)
    q12 = IntegerField(null=True)
    q23 = IntegerField(null=True)
    q34 = IntegerField(null=True)
    xscprox = DecimalField(null=True)
    w1rsemi = DecimalField(null=True)
    w1ba = DecimalField(null=True)
    w1pa = DecimalField(null=True)
    w1gmag = DecimalField(null=True)
    w1gerr = DecimalField(null=True)
    w1gflg = IntegerField(null=True)
    w2rsemi = DecimalField(null=True)
    w2ba = DecimalField(null=True)
    w2pa = DecimalField(null=True)
    w2gmag = DecimalField(null=True)
    w2gerr = DecimalField(null=True)
    w2gflg = IntegerField(null=True)
    w3rsemi = DecimalField(null=True)
    w3ba = DecimalField(null=True)
    w3pa = DecimalField(null=True)
    w3gmag = DecimalField(null=True)
    w3gerr = DecimalField(null=True)
    w3gflg = IntegerField(null=True)
    w4rsemi = DecimalField(null=True)
    w4ba = DecimalField(null=True)
    w4pa = DecimalField(null=True)
    w4gmag = DecimalField(null=True)
    w4gerr = DecimalField(null=True)
    w4gflg = IntegerField(null=True)
    tmass_key = IntegerField(null=True)
    r_2mass = DecimalField(null=True)
    pa_2mass = DecimalField(null=True)
    n_2mass = IntegerField(null=True)
    j_m_2mass = DecimalField(null=True)
    j_msig_2mass = DecimalField(null=True)
    h_m_2mass = DecimalField(null=True)
    h_msig_2mass = DecimalField(null=True)
    k_m_2mass = DecimalField(null=True)
    k_msig_2mass = DecimalField(null=True)
    x = DecimalField(null=True)
    y = DecimalField(null=True)
    z = DecimalField(null=True)
    spt_ind = IntegerField(null=True)
    htm20 = BigIntegerField(null=True)

    class Meta:
        table_name = 'allwise'
        schema = 'catalogdb'
        primary_key = False


class ErositaAGNMock(SDSS5dbModel):
    ero_detuid = TextField(null=True)
    ero_souuid = TextField(null=True)
    ero_ra = FloatField(index=True, null=True)
    ero_dec = FloatField(index=True, null=True)
    ero_radec_err = FloatField(null=True)
    ero_det_like_0 = FloatField(null=True)
    ero_flux = FloatField(index=True, null=True)
    ero_flux_err = FloatField(null=True)
    allwise_designation = TextField(null=True)
    gaia_dr2_source_id = BigIntegerField(null=True)
    nsc_dr1_id = TextField(null=True)
    sdss_dr14_objid = BigIntegerField(null=True)
    target_origin = IntegerField(null=True)
    target_match_prob = FloatField(null=True)
    target_priority = IntegerField(index=True, null=True)
    target_ra = FloatField(index=True, null=True)
    target_dec = FloatField(index=True, null=True)
    target_pmra = FloatField(null=True)
    target_pmdec = FloatField(null=True)
    target_mag_r = FloatField(null=True)
    target_magerr_r = FloatField(null=True)
    t_exp = FloatField(null=True)
    pk = BigAutoField()

    class Meta:
        table_name = 'erosita_agn_mock'
        schema = 'catalogdb'


class ErositaClustersMock(SDSS5dbModel):
    ero_detuid = TextField(null=True)
    ero_souuid = TextField(null=True)
    ero_ra = FloatField(index=True, null=True)
    ero_dec = FloatField(index=True, null=True)
    ero_radec_err = FloatField(null=True)
    ero_det_like_0 = FloatField(null=True)
    ero_flux = FloatField(index=True, null=True)
    ero_flux_err = FloatField(null=True)
    allwise_designation = TextField(null=True)
    gaia_dr2_source_id = BigIntegerField(null=True)
    nsc_dr1_id = TextField(null=True)
    sdss_dr14_objid = BigIntegerField(null=True)
    target_origin = IntegerField(null=True)
    target_match_prob = FloatField(null=True)
    target_priority = IntegerField(index=True, null=True)
    target_ra = FloatField(index=True, null=True)
    target_dec = FloatField(index=True, null=True)
    target_pmra = FloatField(null=True)
    target_pmdec = FloatField(null=True)
    target_mag_r = FloatField(null=True)
    target_magerr_r = FloatField(null=True)
    ero_ext = FloatField(null=True)
    ero_ext_err = FloatField(null=True)
    ero_ext_like = FloatField(null=True)
    t_exp = FloatField(null=True)
    pk = BigAutoField()

    class Meta:
        table_name = 'erosita_clusters_mock'
        schema = 'catalogdb'


class TwoMassPsc(SDSS5dbModel):
    ra = FloatField(index=True, null=True)
    dec = FloatField(column_name='decl', index=True, null=True)
    decl = FloatField(index=True, null=True)
    err_maj = FloatField(null=True)
    err_min = FloatField(null=True)
    err_ang = IntegerField(null=True)
    designation = CharField(null=True, unique=True)
    j_m = FloatField(index=True, null=True)
    j_cmsig = FloatField(null=True)
    j_msigcom = FloatField(null=True)
    j_snr = FloatField(null=True)
    h_m = FloatField(index=True, null=True)
    h_cmsig = FloatField(null=True)
    h_msigcom = FloatField(null=True)
    h_snr = FloatField(null=True)
    k_m = FloatField(index=True, null=True)
    k_cmsig = FloatField(null=True)
    k_msigcom = FloatField(null=True)
    k_snr = FloatField(null=True)
    ph_qual = CharField(index=True, null=True)
    rd_flg = CharField(index=True, null=True)
    bl_flg = CharField(null=True)
    cc_flg = CharField(index=True, null=True)
    ndet = CharField(null=True)
    prox = FloatField(null=True)
    pxpa = IntegerField(null=True)
    pxcntr = IntegerField(null=True)
    gal_contam = IntegerField(index=True, null=True)
    mp_flg = IntegerField(null=True)
    pts_key = AutoField()
    hemis = CharField(null=True)
    date = DateField(null=True)
    scan = IntegerField(null=True)
    glon = FloatField(null=True)
    glat = FloatField(null=True)
    x_scan = FloatField(null=True)
    jdate = FloatField(null=True)
    j_psfchi = FloatField(null=True)
    h_psfchi = FloatField(null=True)
    k_psfchi = FloatField(null=True)
    j_m_stdap = FloatField(null=True)
    j_msig_stdap = FloatField(null=True)
    h_m_stdap = FloatField(null=True)
    h_msig_stdap = FloatField(null=True)
    k_m_stdap = FloatField(null=True)
    k_msig_stdap = FloatField(null=True)
    dist_edge_ns = IntegerField(null=True)
    dist_edge_ew = IntegerField(null=True)
    dist_edge_flg = CharField(null=True)
    dup_src = IntegerField(null=True)
    use_src = IntegerField(null=True)
    a = CharField(null=True)
    dist_opt = FloatField(null=True)
    phi_opt = IntegerField(null=True)
    b_m_opt = FloatField(null=True)
    vr_m_opt = FloatField(null=True)
    nopt_mchs = IntegerField(null=True)
    ext_key = IntegerField(null=True)
    scan_key = IntegerField(null=True)
    coadd_key = IntegerField(null=True)
    coadd = IntegerField(null=True)

    class Meta:
        table_name = 'twomass_psc'
        schema = 'catalogdb'


_GaiaDR2TmassBestNeighbourDeferred = DeferredThroughModel()


class GaiaDR2Source(SDSS5dbModel):
    solution_id = BigIntegerField(index=True, null=True)
    designation = TextField(null=True)
    source_id = BigAutoField(primary_key=True)
    random_index = BigIntegerField(null=True)
    ref_epoch = FloatField(null=True)
    ra = FloatField(index=True, null=True)
    ra_error = FloatField(null=True)
    dec = FloatField(index=True, null=True)
    dec_error = FloatField(null=True)
    parallax = FloatField(index=True, null=True)
    parallax_error = FloatField(null=True)
    parallax_over_error = FloatField(index=True, null=True)
    pmra = FloatField(null=True)
    pmra_error = FloatField(null=True)
    pmdec = FloatField(null=True)
    pmdec_error = FloatField(null=True)
    ra_dec_corr = FloatField(null=True)
    ra_parallax_corr = FloatField(null=True)
    ra_pmra_corr = FloatField(null=True)
    ra_pmdec_corr = FloatField(null=True)
    dec_parallax_corr = FloatField(null=True)
    dec_pmra_corr = FloatField(null=True)
    dec_pmdec_corr = FloatField(null=True)
    parallax_pmra_corr = FloatField(null=True)
    parallax_pmdec_corr = FloatField(null=True)
    pmra_pmdec_corr = FloatField(null=True)
    astrometric_n_obs_al = IntegerField(null=True)
    astrometric_n_obs_ac = IntegerField(null=True)
    astrometric_n_good_obs_al = IntegerField(index=True, null=True)
    astrometric_n_bad_obs_al = IntegerField(null=True)
    astrometric_gof_al = FloatField(null=True)
    astrometric_chi2_al = FloatField(index=True, null=True)
    astrometric_excess_noise = FloatField(null=True)
    astrometric_excess_noise_sig = FloatField(null=True)
    astrometric_params_solved = IntegerField(null=True)
    astrometric_primary_flag = BooleanField(null=True)
    astrometric_weight_al = FloatField(null=True)
    astrometric_pseudo_colour = FloatField(null=True)
    astrometric_pseudo_colour_error = FloatField(null=True)
    mean_varpi_factor_al = FloatField(null=True)
    astrometric_matched_observations = IntegerField(null=True)
    visibility_periods_used = IntegerField(index=True, null=True)
    astrometric_sigma5d_max = FloatField(null=True)
    frame_rotator_object_type = IntegerField(null=True)
    matched_observations = IntegerField(null=True)
    duplicated_source = BooleanField(null=True)
    phot_g_n_obs = IntegerField(null=True)
    phot_g_mean_flux = FloatField(index=True, null=True)
    phot_g_mean_flux_error = FloatField(null=True)
    phot_g_mean_flux_over_error = FloatField(index=True, null=True)
    phot_g_mean_mag = FloatField(index=True, null=True)
    phot_bp_n_obs = IntegerField(null=True)
    phot_bp_mean_flux = FloatField(null=True)
    phot_bp_mean_flux_error = FloatField(null=True)
    phot_bp_mean_flux_over_error = FloatField(index=True, null=True)
    phot_bp_mean_mag = FloatField(index=True, null=True)
    phot_rp_n_obs = IntegerField(null=True)
    phot_rp_mean_flux = FloatField(null=True)
    phot_rp_mean_flux_error = FloatField(null=True)
    phot_rp_mean_flux_over_error = FloatField(index=True, null=True)
    phot_rp_mean_mag = FloatField(index=True, null=True)
    phot_bp_rp_excess_factor = FloatField(index=True, null=True)
    phot_proc_mode = IntegerField(null=True)
    bp_rp = FloatField(null=True)
    bp_g = FloatField(null=True)
    g_rp = FloatField(null=True)
    radial_velocity = FloatField(null=True)
    radial_velocity_error = FloatField(null=True)
    rv_nb_transits = IntegerField(null=True)
    rv_template_teff = FloatField(null=True)
    rv_template_logg = FloatField(null=True)
    rv_template_fe_h = FloatField(null=True)
    phot_variable_flag = TextField(null=True)
    l = FloatField(index=True, null=True)
    b = FloatField(index=True, null=True)
    ecl_lon = FloatField(index=True, null=True)
    ecl_lat = FloatField(index=True, null=True)
    priam_flags = BigIntegerField(null=True)
    teff_val = FloatField(null=True)
    teff_percentile_lower = FloatField(null=True)
    teff_percentile_upper = FloatField(null=True)
    a_g_val = FloatField(null=True)
    a_g_percentile_lower = FloatField(null=True)
    a_g_percentile_upper = FloatField(null=True)
    e_bp_min_rp_val = FloatField(null=True)
    e_bp_min_rp_percentile_lower = FloatField(null=True)
    e_bp_min_rp_percentile_upper = FloatField(null=True)
    flame_flags = BigIntegerField(null=True)
    radius_val = FloatField(null=True)
    radius_percentile_lower = FloatField(null=True)
    radius_percentile_upper = FloatField(null=True)
    lum_val = FloatField(null=True)
    lum_percentile_lower = FloatField(null=True)
    lum_percentile_upper = FloatField(null=True)

    tmass_best_sources = ManyToManyField(TwoMassPsc,
                                         through_model=_GaiaDR2TmassBestNeighbourDeferred,
                                         backref='gaia_best_sources')

    class Meta:
        table_name = 'gaia_dr2_source'
        schema = 'catalogdb'


class GaiaDR2Clean(SDSS5dbModel):

    source_id = BigAutoField(column_name='source_id')
    source = ForeignKeyField(GaiaDR2Source, column_name='source_id', backref='gaia_clean')

    class Meta:
        table_name = 'gaia_dr2_clean'
        schema = 'catalogdb'


class GaiaDR2WDCandidatesV1(SDSS5dbModel):
    white_dwarf_name = TextField(null=True)
    pwd = FloatField(null=True)
    pwd_correction = FloatField(null=True)
    designation = TextField(null=True)
    source_id = BigAutoField(primary_key=True)
    ra = FloatField(index=True, null=True)
    ra_error = FloatField(null=True)
    dec = FloatField(index=True, null=True)
    dec_error = FloatField(null=True)
    parallax = FloatField(null=True)
    parallax_error = FloatField(null=True)
    pmra = FloatField(null=True)
    pmra_error = FloatField(null=True)
    pmdec = FloatField(null=True)
    pmdec_error = FloatField(null=True)
    astrometric_excess_noise = FloatField(null=True)
    astrometric_sigma5d_max = FloatField(null=True)
    phot_g_mean_flux = FloatField(index=True, null=True)
    phot_g_mean_flux_error = FloatField(null=True)
    phot_g_mean_mag = FloatField(index=True, null=True)
    phot_bp_mean_flux = FloatField(null=True)
    phot_bp_mean_flux_error = FloatField(null=True)
    phot_bp_mean_mag = FloatField(null=True)
    phot_rp_mean_flux = FloatField(null=True)
    phot_rp_mean_flux_error = FloatField(null=True)
    phot_rp_mean_mag = FloatField(null=True)
    phot_bp_rp_excess_factor = FloatField(null=True)
    l = FloatField(index=True, null=True)
    b = FloatField(index=True, null=True)
    density = FloatField(null=True)
    ag = FloatField(null=True)
    sdss_name = TextField(null=True)
    umag = FloatField(null=True)
    e_umag = FloatField(null=True)
    gmag = FloatField(null=True)
    e_gmag = FloatField(null=True)
    rmag = FloatField(null=True)
    e_rmag = FloatField(null=True)
    imag = FloatField(null=True)
    e_imag = FloatField(null=True)
    zmag = FloatField(null=True)
    e_zmag = FloatField(null=True)
    teff = FloatField(null=True)
    eteff = FloatField(null=True)
    log_g = FloatField(null=True)
    elog_g = FloatField(null=True)
    mass = FloatField(null=True)
    emass = FloatField(null=True)
    chi2 = FloatField(null=True)
    teff_he = FloatField(null=True)
    eteff_he = FloatField(null=True)
    log_g_he = FloatField(null=True)
    elog_g_he = FloatField(null=True)
    mass_he = FloatField(null=True)
    emass_he = FloatField(null=True)
    chisq_he = FloatField(null=True)

    def gaia_source(self):
        return GaiaDR2Source.select().get_id(self.source_id)

    class Meta:
        table_name = 'gaia_dr2_wd_candidates_v1'
        schema = 'catalogdb'


class GaiaDR2SDSSDR9BestNeighbour(SDSS5dbModel):
    sdssdr9_oid = BigIntegerField(index=True, null=True)
    number_of_neighbours = IntegerField(null=True)
    number_of_mates = IntegerField(null=True)
    best_neighbour_multiplicity = IntegerField(null=True)
    source_id = BigAutoField()
    original_ext_source_id = TextField(null=True)
    angular_distance = FloatField(null=True)
    gaia_astrometric_params = IntegerField(null=True)

    class Meta:
        table_name = 'gaiadr2_sdssdr9_best_neighbour'
        schema = 'catalogdb'


class GalacticGenesis(SDSS5dbModel):
    gaiaid = BigAutoField()
    twomass_desig = CharField(null=True, unique=True)
    g_ra = FloatField(null=True)
    g_dec = FloatField(null=True)
    t_ra = FloatField(null=True)
    t_dec = FloatField(null=True)
    phot_g_mean_mag = FloatField(index=True, null=True)
    h_m = FloatField(index=True, null=True)

    class Meta:
        table_name = 'galactic_genesis'
        schema = 'catalogdb'


class GalacticGenesisBig(SDSS5dbModel):
    gaiaid = BigAutoField()
    twomass_desig = CharField(null=True)
    g_ra = FloatField(null=True)
    g_dec = FloatField(null=True)
    t_ra = FloatField(null=True)
    t_dec = FloatField(null=True)
    phot_g_mean_mag = FloatField(index=True, null=True)
    h_m = FloatField(index=True, null=True)

    class Meta:
        table_name = 'galactic_genesis_big'
        schema = 'catalogdb'


class GUVCat(SDSS5dbModel):
    objid = BigAutoField()
    photoextractid = BigIntegerField(null=True)
    mpstype = TextField(null=True)
    avaspra = FloatField(null=True)
    avaspdec = FloatField(null=True)
    fexptime = FloatField(null=True)
    nexptime = FloatField(null=True)
    ra = FloatField(index=True, null=True)
    dec = FloatField(index=True, null=True)
    glon = FloatField(null=True)
    glat = FloatField(null=True)
    tilenum = IntegerField(null=True)
    img = IntegerField(null=True)
    subvisit = IntegerField(null=True)
    fov_radius = FloatField(null=True)
    type = IntegerField(null=True)
    band = IntegerField(null=True)
    e_bv = FloatField(null=True)
    istherespectrum = IntegerField(null=True)
    chkobj_type = IntegerField(null=True)
    fuv_mag = FloatField(null=True)
    fuv_magerr = FloatField(null=True)
    nuv_mag = FloatField(null=True)
    nuv_magerr = FloatField(null=True)
    fuv_mag_auto = FloatField(null=True)
    fuv_magerr_auto = FloatField(null=True)
    nuv_mag_auto = FloatField(null=True)
    nuv_magerr_auto = FloatField(null=True)
    fuv_mag_aper_4 = FloatField(null=True)
    fuv_magerr_aper_4 = FloatField(null=True)
    nuv_mag_aper_4 = FloatField(null=True)
    nuv_magerr_aper_4 = FloatField(null=True)
    fuv_mag_aper_6 = FloatField(null=True)
    fuv_magerr_aper_6 = FloatField(null=True)
    nuv_mag_aper_6 = FloatField(null=True)
    nuv_magerr_aper_6 = FloatField(null=True)
    fuv_artifact = IntegerField(null=True)
    nuv_artifact = IntegerField(null=True)
    fuv_flags = IntegerField(null=True)
    nuv_flags = IntegerField(null=True)
    fuv_flux = FloatField(null=True)
    fuv_fluxerr = FloatField(null=True)
    nuv_flux = FloatField(null=True)
    nuv_fluxerr = FloatField(null=True)
    fuv_x_image = FloatField(null=True)
    fuv_y_image = FloatField(null=True)
    nuv_x_image = FloatField(null=True)
    nuv_y_image = FloatField(null=True)
    fuv_fwhm_image = FloatField(null=True)
    nuv_fwhm_image = FloatField(null=True)
    fuv_fwhm_world = FloatField(null=True)
    nuv_fwhm_world = FloatField(null=True)
    nuv_class_star = FloatField(null=True)
    fuv_class_star = FloatField(null=True)
    nuv_ellipticity = FloatField(null=True)
    fuv_ellipticity = FloatField(null=True)
    nuv_theta_j2000 = FloatField(null=True)
    nuv_errtheta_j2000 = FloatField(null=True)
    fuv_theta_j2000 = FloatField(null=True)
    fuv_errtheta_j2000 = FloatField(null=True)
    fuv_ncat_fwhm_image = FloatField(null=True)
    fuv_ncat_flux_radius_3 = FloatField(null=True)
    nuv_kron_radius = FloatField(null=True)
    nuv_a_world = FloatField(null=True)
    nuv_b_world = FloatField(null=True)
    fuv_kron_radius = FloatField(null=True)
    fuv_a_world = FloatField(null=True)
    fuv_b_world = FloatField(null=True)
    nuv_weight = FloatField(null=True)
    fuv_weight = FloatField(null=True)
    prob = FloatField(null=True)
    sep = FloatField(null=True)
    nuv_poserr = FloatField(null=True)
    fuv_poserr = FloatField(null=True)
    ib_poserr = FloatField(null=True)
    nuv_pperr = FloatField(null=True)
    fuv_pperr = FloatField(null=True)
    corv = TextField(null=True)
    grank = IntegerField(null=True)
    ngrank = IntegerField(null=True)
    primgid = BigIntegerField(null=True)
    groupgid = TextField(null=True)
    grankdist = IntegerField(null=True)
    ngrankdist = BigIntegerField(null=True)
    primgiddist = BigIntegerField(null=True)
    groupgiddist = TextField(null=True)
    groupgidtot = TextField(null=True)
    difffuv = FloatField(null=True)
    diffnuv = FloatField(null=True)
    difffuvdist = FloatField(null=True)
    diffnuvdist = FloatField(null=True)
    sepas = FloatField(null=True)
    sepasdist = FloatField(null=True)
    inlargeobj = TextField(null=True)
    largeobjsize = FloatField(null=True)

    class Meta:
        table_name = 'guvcat'
        schema = 'catalogdb'


class KeplerInput10(SDSS5dbModel):
    kic_ra = FloatField(index=True, null=True)
    kic_dec = FloatField(index=True, null=True)
    kic_pmra = FloatField(null=True)
    kic_pmdec = FloatField(null=True)
    kic_umag = FloatField(index=True, null=True)
    kic_gmag = FloatField(index=True, null=True)
    kic_rmag = FloatField(index=True, null=True)
    kic_imag = FloatField(index=True, null=True)
    kic_zmag = FloatField(index=True, null=True)
    kic_gredmag = FloatField(null=True)
    kic_d51mag = FloatField(null=True)
    kic_jmag = FloatField(index=True, null=True)
    kic_hmag = FloatField(index=True, null=True)
    kic_kmag = FloatField(index=True, null=True)
    kic_kepmag = FloatField(index=True, null=True)
    kic_kepler_id = BigAutoField()
    kic_tmid = BigIntegerField(null=True)
    kic_scpid = BigIntegerField(null=True)
    kic_altid = BigIntegerField(null=True)
    kic_altsource = BigIntegerField(null=True)
    kic_galaxy = IntegerField(null=True)
    kic_blend = IntegerField(null=True)
    kic_variable = IntegerField(null=True)
    kic_teff = IntegerField(null=True)
    kic_logg = FloatField(null=True)
    kic_feh = FloatField(null=True)
    kic_ebminusv = FloatField(null=True)
    kic_av = FloatField(null=True)
    kic_radius = FloatField(null=True)
    kic_cq = TextField(null=True)
    kic_pq = TextField(null=True)
    kic_aq = IntegerField(null=True)
    kic_catkey = BigIntegerField(null=True)
    kic_scpkey = BigIntegerField(null=True)
    kic_parallax = FloatField(null=True)
    kic_glon = FloatField(index=True, null=True)
    kic_glat = FloatField(index=True, null=True)
    kic_pmtotal = FloatField(null=True)
    kic_grcolor = FloatField(null=True)
    kic_jkcolor = FloatField(null=True)
    kic_gkcolor = FloatField(null=True)
    kic_degree_ra = FloatField(null=True)
    kic_fov_flag = IntegerField(null=True)
    kic_tm_designation = TextField(null=True)

    class Meta:
        table_name = 'kepler_input_10'
        schema = 'catalogdb'


class SDSSDR13Photoobj(SDSS5dbModel):
    objid = BigAutoField()
    run = IntegerField(null=True)
    rerun = IntegerField(null=True)
    camcol = IntegerField(null=True)
    field = IntegerField(null=True)
    obj = IntegerField(null=True)
    type = IntegerField(null=True)
    flags = BigIntegerField(null=True)
    rowc = FloatField(null=True)
    rowcerr = FloatField(null=True)
    colc = FloatField(null=True)
    colcerr = FloatField(null=True)
    rowv = FloatField(null=True)
    rowverr = FloatField(null=True)
    colv = FloatField(null=True)
    colverr = FloatField(null=True)
    sky_u = FloatField(null=True)
    sky_g = FloatField(null=True)
    sky_r = FloatField(null=True)
    sky_i = FloatField(null=True)
    sky_z = FloatField(null=True)
    skyivar_u = FloatField(null=True)
    skyivar_g = FloatField(null=True)
    skyivar_r = FloatField(null=True)
    skyivar_i = FloatField(null=True)
    skyivar_z = FloatField(null=True)
    psfmag_u = FloatField(index=True, null=True)
    psfmag_g = FloatField(index=True, null=True)
    psfmag_r = FloatField(index=True, null=True)
    psfmag_i = FloatField(index=True, null=True)
    psfmag_z = FloatField(index=True, null=True)
    psfmagerr_u = FloatField(null=True)
    psfmagerr_g = FloatField(null=True)
    psfmagerr_r = FloatField(null=True)
    psfmagerr_i = FloatField(null=True)
    psfmagerr_z = FloatField(null=True)
    fibermag_u = FloatField(null=True)
    fibermag_g = FloatField(null=True)
    fibermag_r = FloatField(null=True)
    fibermag_i = FloatField(null=True)
    fibermag_z = FloatField(null=True)
    fibermagerr_u = FloatField(null=True)
    fibermagerr_g = FloatField(null=True)
    fibermagerr_r = FloatField(null=True)
    fibermagerr_i = FloatField(null=True)
    fibermagerr_z = FloatField(null=True)
    fiber2mag_u = FloatField(null=True)
    fiber2mag_g = FloatField(null=True)
    fiber2mag_r = FloatField(null=True)
    fiber2mag_i = FloatField(null=True)
    fiber2mag_z = FloatField(null=True)
    fiber2magerr_u = FloatField(null=True)
    fiber2magerr_g = FloatField(null=True)
    fiber2magerr_r = FloatField(null=True)
    fiber2magerr_i = FloatField(null=True)
    fiber2magerr_z = FloatField(null=True)
    petromag_u = FloatField(null=True)
    petromag_g = FloatField(null=True)
    petromag_r = FloatField(null=True)
    petromag_i = FloatField(null=True)
    petromag_z = FloatField(null=True)
    petromagerr_u = FloatField(null=True)
    petromagerr_g = FloatField(null=True)
    petromagerr_r = FloatField(null=True)
    petromagerr_i = FloatField(null=True)
    petromagerr_z = FloatField(null=True)
    psfflux_u = FloatField(null=True)
    psfflux_g = FloatField(null=True)
    psfflux_r = FloatField(null=True)
    psfflux_i = FloatField(null=True)
    psfflux_z = FloatField(null=True)
    psffluxivar_u = FloatField(null=True)
    psffluxivar_g = FloatField(null=True)
    psffluxivar_r = FloatField(null=True)
    psffluxivar_i = FloatField(null=True)
    psffluxivar_z = FloatField(null=True)
    fiberflux_u = FloatField(null=True)
    fiberflux_g = FloatField(null=True)
    fiberflux_r = FloatField(null=True)
    fiberflux_i = FloatField(null=True)
    fiberflux_z = FloatField(null=True)
    fiberfluxivar_u = FloatField(null=True)
    fiberfluxivar_g = FloatField(null=True)
    fiberfluxivar_r = FloatField(null=True)
    fiberfluxivar_i = FloatField(null=True)
    fiberfluxivar_z = FloatField(null=True)
    fiber2flux_u = FloatField(null=True)
    fiber2flux_g = FloatField(null=True)
    fiber2flux_r = FloatField(null=True)
    fiber2flux_i = FloatField(null=True)
    fiber2flux_z = FloatField(null=True)
    fiber2fluxivar_u = FloatField(null=True)
    fiber2fluxivar_g = FloatField(null=True)
    fiber2fluxivar_r = FloatField(null=True)
    fiber2fluxivar_i = FloatField(null=True)
    fiber2fluxivar_z = FloatField(null=True)
    petroflux_u = FloatField(null=True)
    petroflux_g = FloatField(null=True)
    petroflux_r = FloatField(null=True)
    petroflux_i = FloatField(null=True)
    petroflux_z = FloatField(null=True)
    petrofluxivar_u = FloatField(null=True)
    petrofluxivar_g = FloatField(null=True)
    petrofluxivar_r = FloatField(null=True)
    petrofluxivar_i = FloatField(null=True)
    petrofluxivar_z = FloatField(null=True)
    petrorad_u = FloatField(null=True)
    petrorad_g = FloatField(null=True)
    petrorad_r = FloatField(null=True)
    petrorad_i = FloatField(null=True)
    petrorad_z = FloatField(null=True)
    petroraderr_u = FloatField(null=True)
    petroraderr_g = FloatField(null=True)
    petroraderr_r = FloatField(null=True)
    petroraderr_i = FloatField(null=True)
    petroraderr_z = FloatField(null=True)
    petror50_u = FloatField(null=True)
    petror50_g = FloatField(null=True)
    petror50_r = FloatField(null=True)
    petror50_i = FloatField(null=True)
    petror50_z = FloatField(null=True)
    petror50err_u = FloatField(null=True)
    petror50err_g = FloatField(null=True)
    petror50err_r = FloatField(null=True)
    petror50err_i = FloatField(null=True)
    petror50err_z = FloatField(null=True)
    petror90_u = FloatField(null=True)
    petror90_g = FloatField(null=True)
    petror90_r = FloatField(null=True)
    petror90_i = FloatField(null=True)
    petror90_z = FloatField(null=True)
    petror90err_u = FloatField(null=True)
    petror90err_g = FloatField(null=True)
    petror90err_r = FloatField(null=True)
    petror90err_i = FloatField(null=True)
    petror90err_z = FloatField(null=True)
    mrrcc_u = FloatField(null=True)
    mrrcc_g = FloatField(null=True)
    mrrcc_r = FloatField(null=True)
    mrrcc_i = FloatField(null=True)
    mrrcc_z = FloatField(null=True)
    devflux_u = FloatField(null=True)
    devflux_g = FloatField(null=True)
    devflux_r = FloatField(null=True)
    devflux_i = FloatField(null=True)
    devflux_z = FloatField(null=True)
    devfluxivar_u = FloatField(null=True)
    devfluxivar_g = FloatField(null=True)
    devfluxivar_r = FloatField(null=True)
    devfluxivar_i = FloatField(null=True)
    devfluxivar_z = FloatField(null=True)
    extinction_u = FloatField(null=True)
    extinction_g = FloatField(null=True)
    extinction_r = FloatField(null=True)
    extinction_i = FloatField(null=True)
    extinction_z = FloatField(null=True)
    lnldev_u = FloatField(null=True)
    lnldev_g = FloatField(null=True)
    lnldev_r = FloatField(null=True)
    lnldev_i = FloatField(null=True)
    lnldev_z = FloatField(null=True)
    expflux_u = FloatField(null=True)
    expflux_g = FloatField(null=True)
    expflux_r = FloatField(null=True)
    expflux_i = FloatField(null=True)
    expflux_z = FloatField(null=True)
    expfluxivar_u = FloatField(null=True)
    expfluxivar_g = FloatField(null=True)
    expfluxivar_r = FloatField(null=True)
    expfluxivar_i = FloatField(null=True)
    expfluxivar_z = FloatField(null=True)
    aperflux7_u = FloatField(null=True)
    aperflux7_g = FloatField(null=True)
    aperflux7_r = FloatField(null=True)
    aperflux7_i = FloatField(null=True)
    aperflux7_z = FloatField(null=True)
    calibstatus_u = IntegerField(null=True)
    calibstatus_g = IntegerField(null=True)
    calibstatus_r = IntegerField(null=True)
    calibstatus_i = IntegerField(null=True)
    calibstatus_z = IntegerField(null=True)
    nmgypercount_u = FloatField(null=True)
    nmgypercount_g = FloatField(null=True)
    nmgypercount_r = FloatField(null=True)
    nmgypercount_i = FloatField(null=True)
    nmgypercount_z = FloatField(null=True)
    resolvestatus = IntegerField(null=True)
    thingid = IntegerField(null=True)
    fieldid = BigIntegerField(null=True)
    balkanid = IntegerField(null=True)
    ndetect = IntegerField(null=True)
    psffwhm_u = FloatField(null=True)
    psffwhm_g = FloatField(null=True)
    psffwhm_r = FloatField(null=True)
    psffwhm_i = FloatField(null=True)
    psffwhm_z = FloatField(null=True)
    htmid = BigIntegerField(null=True)
    parentid = BigIntegerField(null=True)
    specobjid = DecimalField(null=True)
    lnlstar_u = FloatField(null=True)
    lnlstar_g = FloatField(null=True)
    lnlstar_r = FloatField(null=True)
    lnlstar_i = FloatField(null=True)
    lnlstar_z = FloatField(null=True)
    lnlexp_u = FloatField(null=True)
    lnlexp_g = FloatField(null=True)
    lnlexp_r = FloatField(null=True)
    lnlexp_i = FloatField(null=True)
    lnlexp_z = FloatField(null=True)
    ra = FloatField(index=True, null=True)
    dec = FloatField(index=True, null=True)
    b = FloatField(index=True, null=True)
    l = FloatField(index=True, null=True)

    class Meta:
        table_name = 'sdss_dr13_photoobj'
        schema = 'catalogdb'


class SDSSDR14APOGEEStar(SDSS5dbModel):
    apstar_id = CharField(primary_key=True)
    target_id = CharField(null=True)
    reduction_id = CharField(null=True)
    file = CharField(null=True)
    apogee_id = CharField(null=True)
    telescope = CharField(null=True)
    location_id = BigIntegerField(null=True)
    field = CharField(null=True)
    ra = FloatField(index=True, null=True)
    dec = FloatField(index=True, null=True)
    glon = FloatField(index=True, null=True)
    glat = FloatField(index=True, null=True)
    apogee_target1 = BigIntegerField(null=True)
    apogee_target2 = BigIntegerField(null=True)
    apogee_target3 = BigIntegerField(null=True)
    apogee2_target1 = BigIntegerField(null=True)
    apogee2_target2 = BigIntegerField(null=True)
    apogee2_target3 = BigIntegerField(null=True)
    min_h = FloatField(null=True)
    max_h = FloatField(null=True)
    min_jk = FloatField(null=True)
    max_jk = FloatField(null=True)
    survey = CharField(null=True)
    extratarg = BigIntegerField(null=True)
    nvisits = BigIntegerField(null=True)
    commiss = BigIntegerField(null=True)
    snr = FloatField(null=True)
    starflag = BigIntegerField(null=True)
    andflag = BigIntegerField(null=True)
    vhelio_avg = FloatField(null=True)
    vscatter = FloatField(null=True)
    verr = FloatField(null=True)
    verr_med = FloatField(null=True)
    synthvhelio_avg = FloatField(null=True)
    synthvscatter = FloatField(null=True)
    synthverr = FloatField(null=True)
    synthverr_med = FloatField(null=True)
    rv_teff = FloatField(null=True)
    rv_logg = FloatField(null=True)
    rv_feh = FloatField(null=True)
    rv_ccfwhm = FloatField(null=True)
    rv_autofwhm = FloatField(null=True)
    synthscatter = FloatField(null=True)
    stablerv_chi2 = FloatField(null=True)
    stablerv_rchi2 = FloatField(null=True)
    chi2_threshold = FloatField(null=True)
    stablerv_chi2_prob = FloatField(null=True)
    apstar_version = CharField(null=True)
    htmid = BigIntegerField(null=True)

    class Meta:
        table_name = 'sdss_dr14_apogeestar'
        schema = 'catalogdb'


class SDSSDR14APOGEEStarVisit(SDSS5dbModel):
    visit_id = CharField(primary_key=True)
    apstar_id = CharField(index=True, null=True)

    class Meta:
        table_name = 'sdss_dr14_apogeestarvisit'
        schema = 'catalogdb'


class SDSSDR14APOGEEVisit(SDSS5dbModel):
    visit_id = CharField(primary_key=True)
    apred_version = CharField(null=True)
    apogee_id = CharField(null=True)
    target_id = CharField(null=True)
    reduction_id = CharField(null=True)
    file = CharField(null=True)
    fiberid = BigIntegerField(null=True)
    plate = CharField(null=True)
    mjd = BigIntegerField(null=True)
    telescope = CharField(null=True)
    location_id = BigIntegerField(null=True)
    ra = FloatField(index=True, null=True)
    dec = FloatField(index=True, null=True)
    glon = FloatField(index=True, null=True)
    glat = FloatField(index=True, null=True)
    apogee_target1 = BigIntegerField(null=True)
    apogee_target2 = BigIntegerField(null=True)
    apogee_target3 = BigIntegerField(null=True)
    apogee2_target1 = BigIntegerField(null=True)
    apogee2_target2 = BigIntegerField(null=True)
    apogee2_target3 = BigIntegerField(null=True)
    min_h = FloatField(null=True)
    max_h = FloatField(null=True)
    min_jk = FloatField(null=True)
    max_jk = FloatField(null=True)
    survey = CharField(null=True)
    extratarg = BigIntegerField(null=True)
    snr = FloatField(null=True)
    starflag = BigIntegerField(null=True)
    dateobs = CharField(null=True)
    jd = FloatField(null=True)
    bc = FloatField(null=True)
    vtype = FloatField(null=True)
    vrel = FloatField(null=True)
    vrelerr = FloatField(null=True)
    vhelio = FloatField(null=True)
    chisq = FloatField(null=True)
    rv_feh = FloatField(null=True)
    rv_teff = FloatField(null=True)
    rv_logg = FloatField(null=True)
    rv_alpha = FloatField(null=True)
    rv_carb = FloatField(null=True)
    synthfile = CharField(null=True)
    estvtype = BigIntegerField(null=True)
    estvrel = FloatField(null=True)
    estvrelerr = FloatField(null=True)
    estvhelio = FloatField(null=True)
    synthvrel = FloatField(null=True)
    synthvrelerr = FloatField(null=True)
    synthvhelio = FloatField(null=True)

    class Meta:
        table_name = 'sdss_dr14_apogeevisit'
        schema = 'catalogdb'


class SDSSDR14ASCAPStar(SDSS5dbModel):
    apstar_id = CharField(primary_key=True)
    target_id = CharField(index=True, null=True)
    aspcap_id = CharField(null=True)
    apogee_id = CharField(index=True, null=True)
    aspcap_version = CharField(null=True)
    results_version = CharField(null=True)
    teff = FloatField(null=True)
    teff_err = FloatField(null=True)
    teff_flag = IntegerField(null=True)
    logg = FloatField(null=True)
    logg_err = FloatField(null=True)
    logg_flag = IntegerField(null=True)
    vmicro = FloatField(null=True)
    vmacro = FloatField(null=True)
    vsini = FloatField(null=True)
    m_h = FloatField(null=True)
    m_h_err = FloatField(null=True)
    m_h_flag = IntegerField(null=True)
    alpha_m = FloatField(null=True)
    alpha_m_err = FloatField(null=True)
    alpha_m_flag = IntegerField(null=True)
    aspcap_chi2 = FloatField(null=True)
    aspcap_class = CharField(null=True)
    aspcapflag = BigIntegerField(null=True)
    fparam_teff = FloatField(null=True)
    fparam_logg = FloatField(null=True)
    fparam_logvmicro = FloatField(null=True)
    fparam_m_h = FloatField(null=True)
    fparam_c_m = FloatField(null=True)
    fparam_n_m = FloatField(null=True)
    fparam_alpha_m = FloatField(null=True)
    param_c_m = FloatField(null=True)
    param_c_m_flag = IntegerField(null=True)
    param_n_m = FloatField(null=True)
    param_n_m_flag = IntegerField(null=True)
    c_fe = FloatField(null=True)
    c_fe_err = FloatField(null=True)
    c_fe_flag = IntegerField(null=True)
    ci_fe = FloatField(null=True)
    ci_fe_err = FloatField(null=True)
    ci_fe_flag = IntegerField(null=True)
    n_fe = FloatField(null=True)
    n_fe_err = FloatField(null=True)
    n_fe_flag = IntegerField(null=True)
    o_fe = FloatField(null=True)
    o_fe_err = FloatField(null=True)
    o_fe_flag = IntegerField(null=True)
    na_fe = FloatField(null=True)
    na_fe_err = FloatField(null=True)
    na_fe_flag = IntegerField(null=True)
    mg_fe = FloatField(null=True)
    mg_fe_err = FloatField(null=True)
    mg_fe_flag = IntegerField(null=True)
    al_fe = FloatField(null=True)
    al_fe_err = FloatField(null=True)
    al_fe_flag = IntegerField(null=True)
    si_fe = FloatField(null=True)
    si_fe_err = FloatField(null=True)
    si_fe_flag = IntegerField(null=True)
    p_fe = FloatField(null=True)
    p_fe_err = FloatField(null=True)
    p_fe_flag = IntegerField(null=True)
    s_fe = FloatField(null=True)
    s_fe_err = FloatField(null=True)
    s_fe_flag = IntegerField(null=True)
    k_fe = FloatField(null=True)
    k_fe_err = FloatField(null=True)
    k_fe_flag = IntegerField(null=True)
    ca_fe = FloatField(null=True)
    ca_fe_err = FloatField(null=True)
    ca_fe_flag = IntegerField(null=True)
    ti_fe = FloatField(null=True)
    ti_fe_err = FloatField(null=True)
    ti_fe_flag = IntegerField(null=True)
    tiii_fe = FloatField(null=True)
    tiii_fe_err = FloatField(null=True)
    tiii_fe_flag = IntegerField(null=True)
    v_fe = FloatField(null=True)
    v_fe_err = FloatField(null=True)
    v_fe_flag = IntegerField(null=True)
    cr_fe = FloatField(null=True)
    cr_fe_err = FloatField(null=True)
    cr_fe_flag = IntegerField(null=True)
    mn_fe = FloatField(null=True)
    mn_fe_err = FloatField(null=True)
    mn_fe_flag = IntegerField(null=True)
    fe_h = FloatField(null=True)
    fe_h_err = FloatField(null=True)
    fe_h_flag = IntegerField(null=True)
    co_fe = FloatField(null=True)
    co_fe_err = FloatField(null=True)
    co_fe_flag = IntegerField(null=True)
    ni_fe = FloatField(null=True)
    ni_fe_err = FloatField(null=True)
    ni_fe_flag = IntegerField(null=True)
    cu_fe = FloatField(null=True)
    cu_fe_err = FloatField(null=True)
    cu_fe_flag = IntegerField(null=True)
    ge_fe = FloatField(null=True)
    ge_fe_err = FloatField(null=True)
    ge_fe_flag = IntegerField(null=True)
    rb_fe = FloatField(null=True)
    rb_fe_err = FloatField(null=True)
    rb_fe_flag = IntegerField(null=True)
    y_fe = FloatField(null=True)
    y_fe_err = FloatField(null=True)
    y_fe_flag = IntegerField(null=True)
    nd_fe = FloatField(null=True)
    nd_fe_err = FloatField(null=True)
    nd_fe_flag = IntegerField(null=True)
    felem_c_m = FloatField(null=True)
    felem_c_m_err = FloatField(null=True)
    felem_ci_m = FloatField(null=True)
    felem_ci_m_err = FloatField(null=True)
    felem_n_m = FloatField(null=True)
    felem_n_m_err = FloatField(null=True)
    felem_o_m = FloatField(null=True)
    felem_o_m_err = FloatField(null=True)
    felem_na_h = FloatField(null=True)
    felem_na_h_err = FloatField(null=True)
    felem_mg_m = FloatField(null=True)
    felem_mg_m_err = FloatField(null=True)
    felem_al_h = FloatField(null=True)
    felem_al_h_err = FloatField(null=True)
    felem_si_m = FloatField(null=True)
    felem_si_m_err = FloatField(null=True)
    felem_p_m = FloatField(null=True)
    felem_p_m_err = FloatField(null=True)
    felem_s_m = FloatField(null=True)
    felem_s_m_err = FloatField(null=True)
    felem_k_h = FloatField(null=True)
    felem_k_h_err = FloatField(null=True)
    felem_ca_m = FloatField(null=True)
    felem_ca_m_err = FloatField(null=True)
    felem_ti_m = FloatField(null=True)
    felem_ti_m_err = FloatField(null=True)
    felem_tiii_m = FloatField(null=True)
    felem_tiii_m_err = FloatField(null=True)
    felem_v_h = FloatField(null=True)
    felem_v_h_err = FloatField(null=True)
    felem_cr_h = FloatField(null=True)
    felem_cr_h_err = FloatField(null=True)
    felem_mn_h = FloatField(null=True)
    felem_mn_h_err = FloatField(null=True)
    felem_fe_h = FloatField(null=True)
    felem_fe_h_err = FloatField(null=True)
    felem_co_h = FloatField(null=True)
    felem_co_h_err = FloatField(null=True)
    felem_ni_h = FloatField(null=True)
    felem_ni_h_err = FloatField(null=True)
    felem_cu_h = FloatField(null=True)
    felem_cu_h_err = FloatField(null=True)
    felem_ge_h = FloatField(null=True)
    felem_ge_h_err = FloatField(null=True)
    felem_rb_h = FloatField(null=True)
    felem_rb_h_err = FloatField(null=True)
    felem_y_h = FloatField(null=True)
    felem_y_h_err = FloatField(null=True)
    felem_nd_h = FloatField(null=True)
    felem_nd_h_err = FloatField(null=True)

    class Meta:
        table_name = 'sdss_dr14_ascapstar'
        schema = 'catalogdb'


class SDSSDR14CannonStar(SDSS5dbModel):
    apogee_id = CharField(index=True, null=True)
    cannon_id = CharField(primary_key=True)
    filename = CharField(null=True)
    location_id = BigIntegerField(null=True)
    field = CharField(null=True)
    teff = FloatField(null=True)
    logg = FloatField(null=True)
    m_h = FloatField(null=True)
    alpha_m = FloatField(null=True)
    fe_h = FloatField(null=True)
    c_h = FloatField(null=True)
    ci_h = FloatField(null=True)
    n_h = FloatField(null=True)
    o_h = FloatField(null=True)
    na_h = FloatField(null=True)
    mg_h = FloatField(null=True)
    al_h = FloatField(null=True)
    si_h = FloatField(null=True)
    p_h = FloatField(null=True)
    s_h = FloatField(null=True)
    k_h = FloatField(null=True)
    ca_h = FloatField(null=True)
    ti_h = FloatField(null=True)
    tiii_h = FloatField(null=True)
    v_h = FloatField(null=True)
    cr_h = FloatField(null=True)
    mn_h = FloatField(null=True)
    co_h = FloatField(null=True)
    ni_h = FloatField(null=True)
    teff_rawerr = FloatField(null=True)
    logg_rawerr = FloatField(null=True)
    m_h_rawerr = FloatField(null=True)
    alpha_m_rawerr = FloatField(null=True)
    fe_h_rawerr = FloatField(null=True)
    c_h_rawerr = FloatField(null=True)
    ci_h_rawerr = FloatField(null=True)
    n_h_rawerr = FloatField(null=True)
    o_h_rawerr = FloatField(null=True)
    na_h_rawerr = FloatField(null=True)
    mg_h_rawerr = FloatField(null=True)
    al_h_rawerr = FloatField(null=True)
    si_h_rawerr = FloatField(null=True)
    p_h_rawerr = FloatField(null=True)
    s_h_rawerr = FloatField(null=True)
    k_h_rawerr = FloatField(null=True)
    ca_h_rawerr = FloatField(null=True)
    ti_h_rawerr = FloatField(null=True)
    tiii_h_rawerr = FloatField(null=True)
    v_h_rawerr = FloatField(null=True)
    cr_h_rawerr = FloatField(null=True)
    mn_h_rawerr = FloatField(null=True)
    co_h_rawerr = FloatField(null=True)
    ni_h_rawerr = FloatField(null=True)
    teff_err = FloatField(null=True)
    logg_err = FloatField(null=True)
    m_h_err = FloatField(null=True)
    alpha_m_err = FloatField(null=True)
    fe_h_err = FloatField(null=True)
    c_h_err = FloatField(null=True)
    ci_h_err = FloatField(null=True)
    n_h_err = FloatField(null=True)
    o_h_err = FloatField(null=True)
    na_h_err = FloatField(null=True)
    mg_h_err = FloatField(null=True)
    al_h_err = FloatField(null=True)
    si_h_err = FloatField(null=True)
    p_h_err = FloatField(null=True)
    s_h_err = FloatField(null=True)
    k_h_err = FloatField(null=True)
    ca_h_err = FloatField(null=True)
    ti_h_err = FloatField(null=True)
    tiii_h_err = FloatField(null=True)
    v_h_err = FloatField(null=True)
    cr_h_err = FloatField(null=True)
    mn_h_err = FloatField(null=True)
    co_h_err = FloatField(null=True)
    ni_h_err = FloatField(null=True)
    chi_sq = FloatField(null=True)
    r_chi_sq = FloatField(null=True)

    class Meta:
        table_name = 'sdss_dr14_cannonstar'
        schema = 'catalogdb'


class SDSSDR14SpecObj(SDSS5dbModel):
    specobjid = DecimalField(primary_key=True)
    bestobjid = BigIntegerField(index=True, null=True)
    fluxobjid = BigIntegerField(index=True, null=True)
    targetobjid = BigIntegerField(index=True, null=True)
    plateid = DecimalField(null=True)
    scienceprimary = IntegerField(null=True)
    sdssprimary = IntegerField(null=True)
    legacyprimary = IntegerField(null=True)
    segueprimary = IntegerField(null=True)
    segue1primary = IntegerField(null=True)
    segue2primary = IntegerField(null=True)
    bossprimary = IntegerField(null=True)
    bossspecobjid = IntegerField(null=True)
    firstrelease = CharField(null=True)
    survey = CharField(null=True)
    instrument = CharField(null=True)
    programname = CharField(null=True)
    chunk = CharField(null=True)
    platerun = CharField(null=True)
    mjd = IntegerField(null=True)
    plate = IntegerField(null=True)
    fiberid = IntegerField(null=True)
    run1d = CharField(null=True)
    run2d = CharField(null=True)
    tile = IntegerField(null=True)
    designid = IntegerField(null=True)
    legacy_target1 = BigIntegerField(null=True)
    legacy_target2 = BigIntegerField(null=True)
    special_target1 = BigIntegerField(null=True)
    special_target2 = BigIntegerField(null=True)
    segue1_target1 = BigIntegerField(null=True)
    segue1_target2 = BigIntegerField(null=True)
    segue2_target1 = BigIntegerField(null=True)
    segue2_target2 = BigIntegerField(null=True)
    boss_target1 = BigIntegerField(null=True)
    eboss_target0 = BigIntegerField(null=True)
    eboss_target1 = BigIntegerField(null=True)
    eboss_target2 = BigIntegerField(null=True)
    eboss_target_id = BigIntegerField(null=True)
    ancillary_target1 = BigIntegerField(null=True)
    ancillary_target2 = BigIntegerField(null=True)
    thing_id_targeting = BigIntegerField(null=True)
    thing_id = IntegerField(null=True)
    primtarget = BigIntegerField(null=True)
    sectarget = BigIntegerField(null=True)
    spectrographid = IntegerField(null=True)
    sourcetype = CharField(null=True)
    targettype = CharField(null=True)
    ra = FloatField(index=True, null=True)
    dec = FloatField(index=True, null=True)
    cx = FloatField(null=True)
    cy = FloatField(null=True)
    cz = FloatField(null=True)
    xfocal = FloatField(null=True)
    yfocal = FloatField(null=True)
    lambdaeff = FloatField(null=True)
    bluefiber = IntegerField(null=True)
    zoffset = FloatField(null=True)
    z = FloatField(null=True)
    zerr = FloatField(null=True)
    zwarning = IntegerField(null=True)
    class_ = CharField(column_name='class', null=True)
    subclass = CharField(null=True)
    rchi2 = FloatField(null=True)
    dof = FloatField(null=True)
    rchi2diff = FloatField(null=True)
    z_noqso = FloatField(null=True)
    zerr_noqso = FloatField(null=True)
    zwarning_noqso = IntegerField(null=True)
    class_noqso = CharField(null=True)
    subclass_noqso = CharField(null=True)
    rchi2diff_noqso = FloatField(null=True)
    z_person = FloatField(null=True)
    class_person = CharField(null=True)
    comments_person = CharField(null=True)
    tfile = CharField(null=True)
    tcolumn_0 = IntegerField(null=True)
    tcolumn_1 = IntegerField(null=True)
    tcolumn_2 = IntegerField(null=True)
    tcolumn_3 = IntegerField(null=True)
    tcolumn_4 = IntegerField(null=True)
    tcolumn_5 = IntegerField(null=True)
    tcolumn_6 = IntegerField(null=True)
    tcolumn_7 = IntegerField(null=True)
    tcolumn_8 = IntegerField(null=True)
    tcolumn_9 = IntegerField(null=True)
    npoly = FloatField(null=True)
    theta_0 = FloatField(null=True)
    theta_1 = FloatField(null=True)
    theta_2 = FloatField(null=True)
    theta_3 = FloatField(null=True)
    theta_4 = FloatField(null=True)
    theta_5 = FloatField(null=True)
    theta_6 = FloatField(null=True)
    theta_7 = FloatField(null=True)
    theta_8 = FloatField(null=True)
    theta_9 = FloatField(null=True)
    veldisp = FloatField(null=True)
    veldisperr = FloatField(null=True)
    veldispz = FloatField(null=True)
    veldispzerr = FloatField(null=True)
    veldispchi2 = FloatField(null=True)
    veldispnpix = IntegerField(null=True)
    veldispdof = IntegerField(null=True)
    wavemin = FloatField(null=True)
    wavemax = FloatField(null=True)
    wcoverage = FloatField(null=True)
    snmedian_u = FloatField(null=True)
    snmedian_g = FloatField(null=True)
    snmedian_r = FloatField(null=True)
    snmedian_i = FloatField(null=True)
    snmedian_z = FloatField(null=True)
    snmedian = FloatField(null=True)
    chi68p = FloatField(null=True)
    fracnsigma_1 = FloatField(null=True)
    fracnsigma_2 = FloatField(null=True)
    fracnsigma_3 = FloatField(null=True)
    fracnsigma_4 = FloatField(null=True)
    fracnsigma_5 = FloatField(null=True)
    fracnsigma_6 = FloatField(null=True)
    fracnsigma_7 = FloatField(null=True)
    fracnsigma_8 = FloatField(null=True)
    fracnsigma_9 = FloatField(null=True)
    fracnsigma_10 = FloatField(null=True)
    fracnsighi_1 = FloatField(null=True)
    fracnsighi_2 = FloatField(null=True)
    fracnsighi_3 = FloatField(null=True)
    fracnsighi_4 = FloatField(null=True)
    fracnsighi_5 = FloatField(null=True)
    fracnsighi_6 = FloatField(null=True)
    fracnsighi_7 = FloatField(null=True)
    fracnsighi_8 = FloatField(null=True)
    fracnsighi_9 = FloatField(null=True)
    fracnsighi_10 = FloatField(null=True)
    fracnsiglo_1 = FloatField(null=True)
    fracnsiglo_2 = FloatField(null=True)
    fracnsiglo_3 = FloatField(null=True)
    fracnsiglo_4 = FloatField(null=True)
    fracnsiglo_5 = FloatField(null=True)
    fracnsiglo_6 = FloatField(null=True)
    fracnsiglo_7 = FloatField(null=True)
    fracnsiglo_8 = FloatField(null=True)
    fracnsiglo_9 = FloatField(null=True)
    fracnsiglo_10 = FloatField(null=True)
    spectroflux_u = FloatField(null=True)
    spectroflux_g = FloatField(null=True)
    spectroflux_r = FloatField(null=True)
    spectroflux_i = FloatField(null=True)
    spectroflux_z = FloatField(null=True)
    spectrosynflux_u = FloatField(null=True)
    spectrosynflux_g = FloatField(null=True)
    spectrosynflux_r = FloatField(null=True)
    spectrosynflux_i = FloatField(null=True)
    spectrosynflux_z = FloatField(null=True)
    spectrofluxivar_u = FloatField(null=True)
    spectrofluxivar_g = FloatField(null=True)
    spectrofluxivar_r = FloatField(null=True)
    spectrofluxivar_i = FloatField(null=True)
    spectrofluxivar_z = FloatField(null=True)
    spectrosynfluxivar_u = FloatField(null=True)
    spectrosynfluxivar_g = FloatField(null=True)
    spectrosynfluxivar_r = FloatField(null=True)
    spectrosynfluxivar_i = FloatField(null=True)
    spectrosynfluxivar_z = FloatField(null=True)
    spectroskyflux_u = FloatField(null=True)
    spectroskyflux_g = FloatField(null=True)
    spectroskyflux_r = FloatField(null=True)
    spectroskyflux_i = FloatField(null=True)
    spectroskyflux_z = FloatField(null=True)
    anyandmask = IntegerField(null=True)
    anyormask = IntegerField(null=True)
    platesn2 = FloatField(null=True)
    deredsn2 = FloatField(null=True)
    snturnoff = FloatField(null=True)
    sn1_g = FloatField(null=True)
    sn1_r = FloatField(null=True)
    sn1_i = FloatField(null=True)
    sn2_g = FloatField(null=True)
    sn2_r = FloatField(null=True)
    sn2_i = FloatField(null=True)
    elodiefilename = CharField(null=True)
    elodieobject = CharField(null=True)
    elodiesptype = CharField(null=True)
    elodiebv = FloatField(null=True)
    elodieteff = FloatField(null=True)
    elodielogg = FloatField(null=True)
    elodiefeh = FloatField(null=True)
    elodiez = FloatField(null=True)
    elodiezerr = FloatField(null=True)
    elodiezmodelerr = FloatField(null=True)
    elodierchi2 = FloatField(null=True)
    elodiedof = FloatField(null=True)
    htmid = BigIntegerField(null=True)
    loadversion = IntegerField(null=True)

    class Meta:
        table_name = 'sdss_dr14_specobj'
        schema = 'catalogdb'


class TessInputV6(SDSS5dbModel):
    id = BigAutoField()
    version = TextField(null=True)
    hip = IntegerField(null=True)
    tyc = TextField(null=True)
    ucac = TextField(null=True)
    twomass = TextField(null=True)
    sdss = BigIntegerField(null=True)
    allwise = TextField(null=True)
    gaia = TextField(null=True)
    apass = TextField(null=True)
    kic = IntegerField(null=True)
    objtype = TextField(null=True)
    typesrc = TextField(null=True)
    ra = FloatField(index=True, null=True)
    dec = FloatField(index=True, null=True)
    posflag = TextField(null=True)
    pmra = FloatField(null=True)
    e_pmra = FloatField(null=True)
    pmdec = FloatField(null=True)
    e_pmdec = FloatField(null=True)
    pmflag = TextField(null=True)
    plx = FloatField(null=True)
    e_plx = FloatField(null=True)
    parflag = TextField(null=True)
    gallong = FloatField(index=True, null=True)
    gallat = FloatField(index=True, null=True)
    eclong = FloatField(null=True)
    eclat = FloatField(null=True)
    bmag = FloatField(index=True, null=True)
    e_bmag = FloatField(null=True)
    vmag = FloatField(index=True, null=True)
    e_vmag = FloatField(null=True)
    umag = FloatField(index=True, null=True)
    e_umag = FloatField(null=True)
    gmag = FloatField(index=True, null=True)
    e_gmag = FloatField(null=True)
    rmag = FloatField(index=True, null=True)
    e_rmag = FloatField(null=True)
    imag = FloatField(index=True, null=True)
    e_imag = FloatField(null=True)
    zmag = FloatField(index=True, null=True)
    e_zmag = FloatField(null=True)
    jmag = FloatField(index=True, null=True)
    e_jmag = FloatField(null=True)
    hmag = FloatField(index=True, null=True)
    e_hmag = FloatField(null=True)
    kmag = FloatField(index=True, null=True)
    e_kmag = FloatField(null=True)
    twomflag = TextField(null=True)
    prox = FloatField(null=True)
    w1mag = FloatField(null=True)
    e_w1mag = FloatField(null=True)
    w2mag = FloatField(null=True)
    e_w2mag = FloatField(null=True)
    w3mag = FloatField(null=True)
    e_w3mag = FloatField(null=True)
    w4mag = FloatField(null=True)
    e_w4mag = FloatField(null=True)
    gaiamag = FloatField(null=True)
    e_gaiamag = FloatField(null=True)
    tmag = FloatField(null=True)
    e_tmag = FloatField(null=True)
    tessflag = TextField(null=True)
    spflag = TextField(null=True)
    teff = FloatField(null=True)
    e_teff = FloatField(null=True)
    logg = FloatField(null=True)
    e_logg = FloatField(null=True)
    mh = FloatField(null=True)
    e_mh = FloatField(null=True)
    rad = FloatField(null=True)
    e_rad = FloatField(null=True)
    mass = FloatField(null=True)
    e_mass = FloatField(null=True)
    rho = FloatField(null=True)
    e_rho = FloatField(null=True)
    lumclass = TextField(null=True)
    lum = FloatField(null=True)
    e_lum = FloatField(null=True)
    d = FloatField(null=True)
    e_d = FloatField(null=True)
    ebv = FloatField(null=True)
    e_ebv = FloatField(null=True)
    numcont = IntegerField(null=True)
    contratio = FloatField(null=True)
    disposition = TextField(null=True)
    duplicate_i = BigIntegerField(null=True)
    priority = FloatField(null=True)
    objid = BigIntegerField(null=True)

    class Meta:
        table_name = 'tess_input_v6'
        schema = 'catalogdb'


class TwoMassClean(SDSS5dbModel):
    pts_key = IntegerField(null=True)
    designation = CharField(primary_key=True)
    ra = FloatField(null=True)
    decl = FloatField(null=True)
    h_m = FloatField(index=True, null=True)
    twomassbrightneighbor = BooleanField(index=True, null=True)

    psc = ForeignKeyField(TwoMassPsc, field='designation',
                          column_name='designation', backref='tmass_clean')

    class Meta:
        table_name = 'twomass_clean'
        schema = 'catalogdb'


class TwoMassCleanNoNeighbor(SDSS5dbModel):
    pts_key = IntegerField(null=True)
    designation = CharField(primary_key=True)
    ra = FloatField(null=True)
    decl = FloatField(null=True)
    h_m = FloatField(index=True, null=True)

    class Meta:
        table_name = 'twomass_clean_noneighbor'
        schema = 'catalogdb'


class GaiaDR2TmassBestNeighbour(SDSS5dbModel):
    tmass_oid = BigIntegerField(index=True, null=True)
    number_of_neighbours = IntegerField(null=True)
    number_of_mates = IntegerField(null=True)
    best_neighbour_multiplicity = IntegerField(null=True)
    source_id = BigAutoField(primary_key=True)
    original_ext_source_id = CharField(null=True)
    angular_distance = FloatField(null=True)
    gaia_astrometric_params = IntegerField(null=True)

    gaia_source = ForeignKeyField(GaiaDR2Source,
                                  column_name='source_id',
                                  backref='tmass_best_neighbour')
    tmass_source = ForeignKeyField(TwoMassPsc,
                                   column_name='original_ext_source_id',
                                   field='designation',
                                   backref='gaia_best_neighbour')

    class Meta:
        table_name = 'gaiadr2_tmass_best_neighbour'
        schema = 'catalogdb'


_GaiaDR2TmassBestNeighbourDeferred.set_model(GaiaDR2TmassBestNeighbour)
